@@ -11,8 +11,8 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+from unittest import mock
 
-import mock
 from oslo_config import cfg
 from oslo_config import fixture as oslo_fixture
 import oslo_messaging as messaging
@@ -26,7 +26,7 @@ from octavia.tests.unit import base
 class TestConsumer(base.TestRpc):
 
     def setUp(self):
-        super(TestConsumer, self).setUp()
+        super().setUp()
         conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         conf.config(host='test-hostname')
         self.conf = conf.conf
@@ -50,7 +50,8 @@ class TestConsumer(base.TestRpc):
         mock_endpoint.assert_called_once_with()
 
     @mock.patch.object(messaging, 'get_rpc_server')
-    def test_consumer_terminate(self, mock_rpc_server):
+    @mock.patch.object(endpoints, 'Endpoints')
+    def test_consumer_terminate(self, mock_endpoint, mock_rpc_server):
         mock_rpc_server_rv = mock.Mock()
         mock_rpc_server.return_value = mock_rpc_server_rv
 
